<?php // phpcs:ignore WordPress.NamingConventions
/**
 * Notes class
 *
 * @author  YITH <plugins@yithemes.com>
 * @package YITH Desktop Notifications for WooCommerce
 * @version 1.0.0
 *
 * @class   YITH_WCDN_Desktop_Notifications_Ajax
 * @package YITH\YITH_Desktop_Notifications_Premium\Classes
 */

if ( ! defined( 'YITH_WCDN_VERSION' ) ) {
	exit( 'Direct access forbidden.' );
}

if ( ! class_exists( 'YITH_WCDN_Desktop_Notifications_Ajax' ) ) {
	/**
	 * YITH_WCDN_Desktop_Notifications_Ajax
	 *
	 * @since 1.0.0
	 */
	class YITH_WCDN_Desktop_Notifications_Ajax {


		/**
		 * Single instance of the class
		 *
		 * @var \YITH_WCDN_Desktop_Notifications_Ajax
		 * @since 1.0.0
		 */
		protected static $instance;


		/**
		 * Returns single instance of the class
		 *
		 * @return \YITH_WCDN_Desktop_Notifications_Ajax
		 * @since 1.0.0
		 */
		public static function get_instance() {
			$self = __CLASS__ . ( class_exists( __CLASS__ . '_Premium' ) ? '_Premium' : '' );

			if ( is_null( $self::$instance ) ) {
				$self::$instance = new $self();
			}

			return $self::$instance;
		}

		/**
		 * Constructor
		 *
		 * @since  1.0.0
		 */
		public function __construct() {
			add_action( 'wp_ajax_yith_wcdn_save_notifications', array( $this, 'yith_wcdn_save_notification' ) );
			add_action( 'wp_ajax_yith_wcdn_display_notifications', array( $this, 'yith_wcdn_display_notifications' ) );
		}

		/**
		 * Save notifications
		 *
		 * @since  1.0.0
		 */
		public function yith_wcdn_save_notification() {
			if ( check_ajax_referer( 'yith_wcdn_ajax-free', 'security' ) ) {
				$option_notification = array(
					'title'             => ( ! isset( $_POST['title'] ) || '' === $_POST['title'] ) ? __( 'Notification', 'yith-desktop-notifications-for-woocommerce' ) : sanitize_text_field( wp_unslash( $_POST['title'] ) ),
					'description'       => isset( $_POST['description'] ) ? sanitize_text_field( wp_unslash( $_POST['description'] ) ) : '',
					'icon'              => isset( $_POST['image'] ) ? sanitize_text_field( wp_unslash( $_POST['image'] ) ) : '',
					'sound'             => isset( $_POST['sound'] ) ? sanitize_text_field( wp_unslash( $_POST['sound'] ) ) : '',
					'time_notification' => isset( $_POST['time_notification'] ) ? intval( wp_unslash( $_POST['time_notification'] ) ) : 0,
					'active'            => 'yes',
					'url'               => null,
				);

				update_option( 'yith-wcdn-desktop-notifications-free', $option_notification );
				die();
			}
		}

		/**
		 * Get notifications to send the user
		 *
		 * @since  1.0.0
		 */
		public function yith_wcdn_display_notifications() {
			$user_notifications = array();
			if ( current_user_can( 'manage_options' ) ) {
				$current_user    = wp_get_current_user();
				$id_current_user = $current_user->ID;
				$instance        = YITH_Desktop_Notifications()->register_notifications;
				$notifications   = $instance->get_notifications_by_user( $current_user );
				foreach ( $notifications as $notification ) {

					$user_notified = (array) unserialize( $notification->notified_users ); //phpcs:ignore -- Serialized data has known vulnerability problems with Object Injection. JSON is generally a better approach for serializing data
					$url           = $notification->url;

					if ( ! in_array( $id_current_user, $user_notified, false ) ) {

						$noti                = (array) unserialize( $notification->data ); //phpcs:ignore -- Serialized data has known vulnerability problems with Object Injection. JSON is generally a better approach for serializing data
						$noti['url']         = $url;
						$noti['title']       = html_entity_decode( $noti['title'], ENT_QUOTES );
						$noti['description'] = html_entity_decode( $noti['description'], ENT_QUOTES );
						array_push( $user_notifications, $noti );

						// Updated array user notified.
						array_push( $user_notified, $id_current_user );
						$instance->update_notification( $notification->id, serialize( $user_notified ) ); //phpcs:ignore -- Serialized data has known vulnerability problems with Object Injection. JSON is generally a better approach for serializing data
						continue;
					}
				}
			}
			wp_send_json( $user_notifications );
		}
	}
}
